```typescript
// job/frontend/src/App.tsx
import React from 'react';
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import JobList from './components/JobList';
import JobDetail from './components/JobDetail';
// import Navbar from './components/Navbar'; // <-- SUPPRIMER CET IMPORT
import Sidebar from './components/Sidebar'; // Garde cet import
import { ThemeProvider, createTheme } from '@mui/material/styles';
import CssBaseline from '@mui/material/CssBaseline';
import Box from '@mui/material/Box';

// Largeur de la sidebar
const drawerWidth = 240; // en pixels, comme dans Notion

// --- Gardez votre thème Material UI 'Notion-like' inchangé ici ---
const customTheme = createTheme({
    palette: {
        mode: 'light',
        primary: { main: '#333333', light: '#555555', dark: '#1a1a1a', contrastText: '#FFFFFF' },
        secondary: { main: '#6A5ACD', light: '#8C7FD9', dark: '#4C3B9B', contrastText: '#FFFFFF' },
        background: { default: '#F7F7F7', paper: '#FFFFFF' },
        text: { primary: '#212121', secondary: '#616161', disabled: '#BDBDBD' },
        error: { main: '#EF9A9A' }, warning: { main: '#FFCC80' }, info: { main: '#90CAF9' }, success: { main: '#A5D6A7' },
    },
    typography: {
        fontFamily: [
            'Inter', 'Roboto', 'Arial', 'sans-serif', '"Apple Color Emoji"', '"Segoe UI Emoji"', '"Segoe UI Symbol"',
        ].join(','),
        h1: { fontSize: '2.5rem', fontWeight: 600, color: '#212121' },
        h2: { fontSize: '2rem', fontWeight: 600, color: '#212121' },
        h3: { fontSize: '1.75rem', fontWeight: 600, color: '#212121' },
        body1: { fontSize: '1rem', lineHeight: 1.6, color: '#212121' },
        body2: { fontSize: '0.875rem', lineHeight: 1.5, color: '#616161' },
        button: { textTransform: 'none' },
    },
    components: {
        MuiAppBar: { // Optionnel : Si vous voulez garder une AppBar très minimale pour des actions spécifiques (sans navigation)
            styleOverrides: {
                colorPrimary: {
                    backgroundColor: '#FFFFFF', color: '#212121', boxShadow: '0px 1px 4px rgba(0, 0, 0, 0.04)',
                },
            },
        },
        MuiButton: {
            styleOverrides: {
                root: { borderRadius: '6px', textTransform: 'none' },
                containedPrimary: {
                    backgroundColor: '#ECEFF1', color: '#212121', boxShadow: 'none',
                    '&:hover': { backgroundColor: '#CFD8DC', boxShadow: 'none' },
                    '&:active': { backgroundColor: '#B0BEC5' },
                },
                containedSecondary: {
                    backgroundColor: '#6A5ACD', color: '#FFFFFF', boxShadow: 'none',
                    '&:hover': { backgroundColor: '#4C3B9B', boxShadow: 'none' },
                },
                outlined: {
                    borderColor: '#CFD8DC', color: '#616161',
                    '&:hover': { borderColor: '#B0BEC5', backgroundColor: 'rgba(0, 0, 0, 0.02)' },
                },
            },
        },
        MuiPaper: {
            styleOverrides: {
                root: {
                    borderRadius: '8px', boxShadow: '0px 2px 8px rgba(0, 0, 0, 0.05)', backgroundColor: '#FFFFFF',
                },
            },
        },
        MuiTextField: {
            defaultProps: { variant: 'outlined' },
            styleOverrides: {
                root: {
                    '& .MuiOutlinedInput-root': {
                        borderRadius: '6px !important', backgroundColor: '#FFFFFF',
                        '&.Mui-focused fieldset': { borderColor: '#B0BEC5' },
                    },
                    '& .MuiInputLabel-root': { color: '#616161' },
                },
            },
        },
        MuiInputBase: {
            styleOverrides: { input: { padding: '12px 14px' } },
        },
        MuiSelect: {
            styleOverrides: { select: { borderRadius: '6px !important', padding: '12px 14px' } },
        },
    },
});
// --- Fin du thème Material UI 'Notion-like' ---

const App: React.FC = () => {
  return (
    <ThemeProvider theme={customTheme}>
      <CssBaseline />
      <Router>
        <Box sx={{ display: 'flex', minHeight: '100vh', backgroundColor: 'background.default' }}> {/* Conteneur principal flex */}

          {/* Sidebar : elle prend sa largeur fixe */}
          <Sidebar drawerWidth={drawerWidth} />

          {/* Contenu principal : prend l'espace restant et a une marge à gauche */}
          <Box
            component="main"
            sx={{
              flexGrow: 1, // Prend l'espace restant
              p: { xs: 2, md: 4 }, // Padding général pour le contenu (réactif)
              width: { sm: `calc(100% - ${drawerWidth}px)` }, // Prend toute la largeur moins la sidebar sur desktop
              ml: { sm: `${drawerWidth}px` }, // Marge à gauche égale à la largeur de la sidebar sur desktop
              // Pas besoin de mt (margin-top) car il n'y a plus de Navbar en haut.
              // S'assure que le contenu peut défiler indépendamment si trop long
              overflowY: 'auto',
              backgroundColor: 'background.default', // Couleur de fond du contenu
            }}
          >
            {/* Ici seront rendues vos routes de contenu */}
            <Routes>
              <Route path="/" element={<JobList />} />
              <Route path="/jobs/:id" element={<JobDetail />} />
            </Routes>
          </Box>
        </Box>
      </Router>
    </ThemeProvider>
  );
};

export default App;
```